diff plugincandidates.h @ 4:6f891a9c6434

Make checker with hard-coded knowledge about various plugin types and paths; fix some process management problems
author Chris Cannam
date Wed, 13 Apr 2016 12:00:07 +0100
parents 2288c1d05c28
children 74064d6f5e07
line wrap: on
line diff
--- a/plugincandidates.h	Wed Apr 13 09:12:04 2016 +0100
+++ b/plugincandidates.h	Wed Apr 13 12:00:07 2016 +0100
@@ -28,7 +28,7 @@
 
     /** Scan the libraries found in the given plugin path (i.e. list
      *  of plugin directories), checking that the given descriptor
      *  function can be looked up in each. Store the results
      *  internally, associated with the given (arbitrary) tag, for
      *  later querying using getCandidateLibrariesFor() and
      *  getFailedLibrariesFor().
@@ -37,12 +37,12 @@
      */
     void scan(std::string tag,
 	      stringlist pluginPath,
-	      std::string descriptorFunctionName);
+	      std::string descriptorSymbolName);
 
     /** Return list of plugin library paths that were checked
      *  successfully during the scan for the given tag.
      */
-    stringlist getCandidateLibrariesFor(std::string tag);
+    stringlist getCandidateLibrariesFor(std::string tag) const;
 
     struct FailureRec {
 	std::string library;
@@ -52,7 +52,7 @@
     /** Return list of failure reports arising from the prior scan for
      *  the given tag. 
      */
-    std::vector<FailureRec> getFailedLibrariesFor(std::string tag);
+    std::vector<FailureRec> getFailedLibrariesFor(std::string tag) const;
 
 private:
     std::string m_helper;
@@ -28,7 +28,7 @@
     /** Scan the libraries found in the given plugin path (i.e. list
      *  of plugin directories), checking that the given descriptor
-     *  function can be looked up in each. Store the results
+     *  symbol can be looked up in each. Store the results
      *  internally, associated with the given (arbitrary) tag, for
      *  later querying using getCandidateLibrariesFor() and